summaryrefslogtreecommitdiffstats
path: root/source/Generating/BioGen.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--source/Generating/BioGen.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/source/Generating/BioGen.h b/source/Generating/BioGen.h
index 0df80967f..88ca3e438 100644
--- a/source/Generating/BioGen.h
+++ b/source/Generating/BioGen.h
@@ -183,7 +183,7 @@ protected:
float m_RiverWidthThreshold;
float m_LandBiomesSize;
- typedef int IntMap[256]; // x + 16 * z, expected trimmed into [0..255] range
+ typedef int IntMap[17 * 17]; // x + 17 * z, expected trimmed into [0..255] range
// cBiomeGen overrides:
virtual void GenBiomes(int a_ChunkX, int a_ChunkZ, cChunkDef::BiomeMap & a_BiomeMap) override;